
![Logo](https://i.ibb.co/80xDDsg/ETools-Logo.png)


# ETools Youtube Downloader

ETools YouTube Downloader is a simple YouTube video downloader using yt-dlp, for use by all python users and other digital creators.


### Authors

- [**Wyatt Johnson**](https://github.com/realendie)


### Features

- Ability to download any YouTube video free of charge.


### Roadmap

- Add the ability to just download audio from video.

- Add the option to use a GUI instead of CMD or Terminal.


### Installation

To install ETools YouTube Downloader run the command:

```
pip install EToolsbyEndie
```


    

## How to Use

**YouTube Video Downloading:**

To download a YouTube video run the command
```download_video``` in command prompt.

**File Type Conversion:**

To convert a file type run the command
```convert_file``` in command prompt.